@@ -3,6 +3,7 @@
 #include "VDetector.hh"
 #include "execNEST.hh"
 #include "DetectorExample_XENON10.hh"
+#include "LUX_Run03.hh"
 #include <pybind11/numpy.h>
 #include <pybind11/stl_bind.h>
 #include <pybind11/stl.h>
@@ -143,7 +144,7 @@ PYBIND11_MODULE(nestpy, m) {
 	.def("OptTrans", &VDetector::OptTrans)
   	.def("SinglePEWaveForm", &VDetector::SinglePEWaveForm);
   
-  //	Binding for example XENONnT
+  //	Binding for example XENON10
   py::class_<DetectorExample_XENON10, VDetector, std::unique_ptr<DetectorExample_XENON10, py::nodelete>>(m, "DetectorExample_XENON10")
      .def(py::init<>())
 	 .def("Initialization", &DetectorExample_XENON10::Initialization)
@@ -151,6 +152,14 @@ PYBIND11_MODULE(nestpy, m) {
 	 .def("OptTrans", &DetectorExample_XENON10::OptTrans)
 	 .def("SinglePEWaveForm", &DetectorExample_XENON10::SinglePEWaveForm);
 
+  //	Binding for example LUX_Run03
+  py::class_<DetectorExample_LUX_RUN03, VDetector, std::unique_ptr<DetectorExample_LUX_RUN03, py::nodelete>>(m, "LUX_RUN3")
+     .def(py::init<>())
+	 .def("Initialization", &DetectorExample_LUX_RUN03::Initialization)
+	 .def("FitTBA", &DetectorExample_LUX_RUN03::FitTBA)
+	 .def("OptTrans", &DetectorExample_LUX_RUN03::OptTrans)
+	 .def("SinglePEWaveForm", &DetectorExample_LUX_RUN03::SinglePEWaveForm);
+
   //	Binding for the NESTcalc class
   py::class_<NEST::NESTcalc, std::unique_ptr<NEST::NESTcalc, py::nodelete>>(m, "NESTcalc")
     //.def(py::init<>())
